<?php
/**
*XML SIS Handball v2
*
 * @package xmlsishandballv2 for Joomla 3
 * @version 4.0.2: icsdata.php 2023-07-04
 * @author Martin Maetz (webmaster@maetzokopter.at)
 * @copyright (C) 2024 Martin Maetz (http://www.maetzokopter.at)
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

// No direct access to this file
defined('_JEXEC') or die;

use Joomla\CMS\Factory;

jimport('joomla.application.component.modeladmin');

class xmlsishandballv2ModelIcsdata extends JModelAdmin {

	/**
     * Method override to check if you can edit an existing record.
     *
     * @param    array     $data    An array of input data.
     * @param    string    $key     The name of the key for the primary key.
     *
     * @return    boolean
     */
    protected function allowEdit($data = array(), $key = 'id')
    {
        // Check specific edit permission then general edit permission.
        return Factory::getUser()
            ->authorise(
                'core.edit',
                'com_xmlsishandballv2.message.' . ((int) isset($data[$key]) ? $data[$key] : 0)
            )
            or parent::allowEdit($data, $key);
    }
 
    /**
     * Returns a reference to the a Table object, always creating it.
     *
     * @param       type    The table type to instantiate
     * @param       string  A prefix for the table class name. Optional.
     * @param       array   Configuration array for model. Optional.
     *
     * @return      JTable  A database object
     */
    public function getTable($type = 'icsdata', $prefix = 'xmlsishandballv2Table', $config = array())
    {
        return JTable::getInstance($type, $prefix, $config);
    }
 
    /**
     * Method to get the record form.
     *
     * @param array   $data     Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     *
     * @return mixed A JForm object on success, false on failure
     */
    public function getForm($data = array(), $loadData = true)
    {
        // Get the form.
        $form = $this->loadForm('com_jxmlsishandballv2.icsdata', 'icsdata',
            array('control' => 'jform', 'load_data' => $loadData)
        );
 
        if (empty($form))
        {
            return false;
        }
 
        return $form;
    }
 
    /**
     * Method to get the script that have to be included on the form
     *
     * @return string Script file
     */
    /*public function getScript()
    {
        return '/administrator/components/com_joomregatta/models/forms/registration.js';
    }*/
 
    /**
     * Method to get the data that should be injected in the form.
     *
     * @return      mixed   The data for the form.
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $data = Factory::getApplication()
            ->getUserState('com_xmlsishandballv2.edit.icsdata.data');
 
        if (empty($data))
        {
            $data = $this->getItem();
        }
 
        return $data;
    }
	
}