<?php
/**
*XML SIS Handball v2
*
 * @package xmlsishandballv2 for Joomla 3
 * @version 4.0.2: xmlsishandballv2vereins.php 2024-01-17
 * @author Martin Maetz (webmaster@maetzokopter.at)
 * @copyright (C) 2024 Martin Maetz (http://www.maetzokopter.at)
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

defined('_JEXEC') or die;
jimport('joomla.application.component.modellist');
class xmlsishandballv2ModelVereins extends JModelList {

	/**
	 * Constructor.
	 *
	 * @param   array  $config  An optional associative array of configuration settings.
	 *
	 * @see     JController
	 * @since   1.6
	 */
	public function __construct($config = array()) {
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'a.id',
				'vereinsname', 'a.vereinsname',
				'vereinsnameshort', 'a.vereinsnameshort',
				'vereinsnummer', 'a.vereinsnummer',
				'nationurl', 'a.nationurl',
				'timezone', 'a.timezone',
				'vereinsurl', 'a.vereinsurl'
			);
		}
		parent::__construct($config);
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @since	1.6
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		//$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $this->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$state = $this->getUserStateFromRequest($this->context.'.filter.state', 'filter_state', '', 'string');
		$this->setState('filter.state', $state);

		$categoryId = $this->getUserStateFromRequest($this->context.'.filter.category_id', 'filter_category_id', '');
		$this->setState('filter.category_id', $categoryId);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_xmlsishandballv2');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('a.id', 'asc');
	}
	
	/**
	 * Method to get a store id based on model configuration state.
	 *
	 * This is necessary because the model is used by the component and
	 * different modules that might need different sets of data or different
	 * ordering requirements.
	 *
	 * @param   string  $id  A prefix for the store id.
	 *
	 * @return  string  A store id.
	 */
	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id .= ':' . $this->getState('filter.search');
		$id .= ':' . $this->getState('filter.access');
		$id .= ':' . $this->getState('filter.state');

		return parent::getStoreId($id);
	}
	
	

	
	protected function getListQuery() {
		$db = $this->getDbo();
		$query = $db->getQuery(true);
		
		$query->select(
			$this->getState(
				'list.select',
				'a.id AS id, a.vereinsname AS vereinsname, a.vereinsnameshort AS vereinsnameshort,'.
				'a.vereinsnummer AS vereinsnummer, a.nationurl AS nationurl,'.
				'a.timezone AS timezone, a.vereinsurl AS vereinsurl,' .
				'a.checked_out AS checked_out,' .
				'a.checked_out_time AS checked_out_time'
			)
		);
		$query->from($db->quoteName('#__xmlsishbv2_verein').' AS a');
		
		// Join over the categories.
		/*$query->select('c.vereinsname AS verein_title');
		$query->join('LEFT', '#__xmlsishbv2_verein AS c ON c.id = a.verein_id');*/
		
		// Filter by category.
		/*$categoryId = $this->getState('filter.category_id');
		if (is_numeric($categoryId)) {
			$query->where('a.verein_id = '.(int) $categoryId);
		}*/
		
		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where('(a.vereinsname LIKE '.$search.' OR a.vereinsnameshort LIKE '.$search.
				'OR a.vereinsnummer LIKE '.$search.' OR a.nationurl LIKE '.$search.
				'OR a.timezone LIKE '.$search.'OR a.vereinsurl LIKE '.$search.')');
			}
		}
		
		//$query->select('*')
		//->from('#__xmlsishbv2_clubs');
		/*$search = $this->getState('filter.search');
		if (!empty($search)) {
			$s = $db->quote('%'.$db->escape($search, true).'%');
			$query->where('a.clubname LIKE' .$s
			.'OR a.clubno LIKE' .$s
			.'OR a.cat_id LIKE' .$s);
		}*/
		/*$sort = $this->getState('list.ordering');
		$order = $this->getState('list.direction');
		$query->order($db->escape($sort).' '.$db->escape($order));*/
		
		// Add the list ordering clause.
		//$orderCol	= $this->state->get('list.ordering', 'ordering');
		//$orderDirn	= $this->state->get('list.direction', 'ASC');
		$ordering = $this->getState('list.ordering', 'ordering');
		//if ($orderCol == 'ordering' || $orderCol == 'category_title') {
		//if ($orderCol == 'verein_title') {
			//$orderCol = 'c.title '.$orderDirn.', a.ordering';
			//$orderCol = 'c.vereinsname '.$orderDirn.', verein_title';
		//}
		/*if($orderCol == 'client_name')
			$orderCol = 'cl.name';*/
		//$query->order($db->escape($orderCol.' '.$orderDirn));
		$query->order($db->escape($ordering) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));
		
		return $query;
	}

	


}