<?php
/**
*XML SIS Handball v2
*
 * @package xmlsishandballv2 for Joomla 3
 * @version 4.0.2: view.html.php 2023-07-04
 * @author Martin Maetz (webmaster@maetzokopter.at)
 * @copyright (C) 2024 Martin Maetz (http://www.maetzokopter.at)
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/


// Den direkten Aufruf verbieten
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;

JLoader::register('xmlsishandballv2Helper', JPATH_ADMINISTRATOR . '/components/com_xmlsishandballv2/helpers/xmlsishandballv2.php');
 
/**
 * HalloWelt View
 */
class xmlsishandballv2ViewClub extends JViewLegacy
{

	/**
	 * The JForm object
	 *
	 * @var  JForm
	 */
	protected $form;

	/**
	 * The active item
	 *
	 * @var  object
	 */
	protected $item;

	/**
	 * The model state
	 *
	 * @var  object
	 */
	protected $state;

	/**
	 * Object containing permissions for the item
	 *
	 * @var  JObject
	 */
	protected $canDo;

	/**
	 * Display the view
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  mixed  A string if successful, otherwise an Error object.
	 */
	public function display($tpl = null)
	{
		$this->form  = $this->get('Form');
		$this->item  = $this->get('Item');
		$this->state = $this->get('State');
		$this->canDo = JHelperContent::getActions('com_xmlsishandballv2');

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors), 500);
		}

		$this->addToolbar();

		return parent::display($tpl);

	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return  void
	 *
	 * @since   1.6
	 */
	protected function addToolbar()
	{
		//Factory::getApplication()->input->set('hidemainmenu', true);

		$user       = Factory::getUser();
		$isNew      = ($this->item->id == 0);
		$checkedOut = !($this->item->checked_out == 0 || $this->item->checked_out == $user->id);
		$canDo      = $this->canDo;

		if (version_compare(JVERSION, '4', '>=')) {
			JToolBarHelper::title(
				$isNew ? Text::_('COM_XMLSISHANDBALLV2_CLUB_NEW') : Text::_('COM_XMLSISHANDBALLV2_CLUB_CHANGE'),
				'shield'
			);
		} else {
			JToolBarHelper::title(
				$isNew ? Text::_('COM_XMLSISHANDBALLV2_CLUB_NEW') : Text::_('COM_XMLSISHANDBALLV2_CLUB_CHANGE'),
				'48-xmlsishandballv2logo'
			);
		}

		// If not checked out, can save the item.
		if (!$checkedOut && ($canDo->get('core.edit') || $canDo->get('core.create')))
		{
			JToolbarHelper::apply('club.apply');
			JToolbarHelper::save('club.save');
		}

		if (!$checkedOut && $canDo->get('core.create'))
		{
			JToolbarHelper::save2new('club.save2new');
		}

		// If an existing item, can save to a copy.
		if (!$isNew && $canDo->get('core.create'))
		{
			JToolbarHelper::save2copy('club.save2copy');
		}

		if (empty($this->item->id))
		{
			JToolbarHelper::cancel('club.cancel');
		}
		else
		{
			if (JComponentHelper::isEnabled('com_contenthistory') && $this->state->params->get('save_history', 0) && $canDo->get('core.edit'))
			{
				JToolbarHelper::versions('com_xmlsishandballv2.club', $this->item->id);
			}

			JToolbarHelper::cancel('club.cancel', 'JTOOLBAR_CLOSE');
		}

	}
 
}