<?php
/**
*XML SIS Handball v2
*
 * @package xmlsishandballv2 for Joomla 3
 * @version 4.0.2: view.html.php 2023-07-04
 * @author Martin Maetz (webmaster@maetzokopter.at)
 * @copyright (C) 2024 Martin Maetz (http://www.maetzokopter.at)
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

defined('_JEXEC') or die;

use Joomla\CMS\Language\Text;

/**
 * View class for a list of clients.
 *
 * @since  1.6
 */
class xmlsishandballv2ViewVereins extends JViewLegacy
{
	protected $items;

	protected $pagination;

	protected $state;

	/**
	 * Display the view
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  void
	 */
	public function display($tpl = null)
	{
		$this->items         = $this->get('Items');
		$this->pagination    = $this->get('Pagination');
		$this->state         = $this->get('State');
		$this->filterForm    = $this->get('FilterForm');
		$this->activeFilters = $this->get('ActiveFilters');

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			//JError::raiseError(500, implode("\n", $errors));
			throw new Exception(implode("\n", $errors), 500);

			return false;
		}

		if (version_compare(JVERSION, '4', '<')) {
			xmlsishandballv2Helper::addSubmenu('vereins');
		}

		if (class_exists('JHtmlSidebar')){
			$this->sidebar = JHtmlSidebar::render();
		}
		
		$this->addToolbar();
		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return  void
	 *
	 * @since   1.6
	 */
	protected function addToolbar()
	{
		require_once JPATH_COMPONENT . '/helpers/xmlsishandballv2.php';

		$canDo = JHelperContent::getActions('com_xmlsishandballv2');

		if (version_compare(JVERSION, '4', '>=')) {
			JToolBarHelper::title(
				Text::_('COM_XMLSISHANDBALLV2_VEREIN_ADMIN'),
				'users'
			);
		} else {
			JToolbarHelper::title(
				Text::_('COM_XMLSISHANDBALLV2_VEREIN_ADMIN'), 
				'48-xmlsishandballv2verein'
			);
		}

		if ($canDo->get('core.create'))
		{
			JToolbarHelper::addNew('verein.add');
		}

		if ($canDo->get('core.edit'))
		{
			JToolbarHelper::editList('verein.edit');
		}

		if ($canDo->get('core.delete'))
		{
			JToolbarHelper::deleteList('', 'vereins.delete', 'JTOOLBAR_DELETE');
		}
		
	}

	/**
	 * Returns an array of fields the table can be sorted by
	 *
	 * @return  array  Array containing the field name to sort by as the key and display text as value
	 *
	 * @since   3.0
	 */
	protected function getSortFields()
	{
		return array(
			'a.vereinsname' => Text::_('COM_XMLSISHANDBALLV2_VEREINS_HEAD_HEADING_VEREINID'),
			'a.vereinsnameshort' => Text::_('COM_XMLSISHANDBALLV2_VEREINS_HEAD_HEADING_ICSTEAM'),
			'a.vereinsnummer' => Text::_('COM_XMLSISHANDBALLV2_VEREINS_HEAD_HEADING_ICSTEAMSHORT'),
			'a.nationurl' => Text::_('COM_XMLSISHANDBALLV2_VEREINS_HEAD_HEADING_LIGANO'),
			'a.timezone' => Text::_('COM_XMLSISHANDBALLV2_VEREINS_HEAD_HEADING_TEAMNO'),
			'a.vereinsurl' => Text::_('COM_XMLSISHANDBALLV2_VEREINS_HEAD_HEADING_TEAMNO1'),
			'a.id' => Text::_('JGRID_HEADING_ID')
		);
	}
}