﻿<?php
/**
*XML SIS Handball v2
*
 * @package xmlsishandballv2 for Joomla 3
 * @version 4.0.2: xmlsishandballv2.php 2023-08-08
 * @author Martin Maetz (webmaster@maetzokopter.at)
 * @copyright (C) 2024 Martin Maetz (http://www.maetzokopter.at)
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

defined('_JEXEC') or die;

use Joomla\CMS\Factory;

abstract class xmlsishandballv2Helper
{

	static function getParameter($vereinsnummer,$vereinspasswort,$liganummer,$sis_art) {
		$parameter = array(
			'user' => $vereinsnummer,
			'pass' => $vereinspasswort,
			'art'  => $sis_art,
			'auf'  => $liganummer
		);
		return $parameter;
	}

	//New with sql
	//public function downloadData($linkresults,$parameter) {
	static function downloadData($linkresults,$parameter) {
		$postdata = http_build_query($parameter);

		$ctx = stream_context_create(
			array( 
				'http' => array( 
					'timeout' => 60,
					'method'  => 'POST',
					'header'  => 'Content-type: application/x-www-form-urlencoded',
					'content' => $postdata
				) 
			) 
		);

		return @file_get_contents($linkresults,0,$ctx);
	}
	
	public static function refreshData($linkresults, $linkparameters, $liganummer, $sis_art) {

		$db = Factory::getDbo();

		// Conditions for which records should be updated.
		$conditions = array(
			$db->quoteName('liga_nr') . ' = ' . $db->quote($liganummer),
			$db->quoteName('sis_art') . ' = ' . $db->quote($sis_art)
		);

		$query = $db->getQuery(true);
		$query->select($db->quoteName(array('liga_nr', 'sis_art', 'last_updated', 'started_download')));
		$query->from($db->quoteName('#__xmlsishbv2_data'));
		$query->where($conditions);
 
		$db->setQuery($query);
		$daten = $db->loadObjectList();

		if(!$daten) {
			//echo 'Datensatz für Liga + Sis_art wurde nicht gefunden -> dummy eingefügen';

			$profile = new stdClass();
			$profile->liga_nr = $liganummer;
			$profile->sis_art = $sis_art;
			$profile->last_updated = null;
			$result = Factory::getDbo()->insertObject('#__xmlsishbv2_data', $profile);

		}
		
		$verein_user = $linkparameters['user'];
		$timezone = xmlsishandballv2Helper::getTimezone($verein_user);
		date_default_timezone_set($timezone[0]->timezone);
		$content_params = JComponentHelper::getParams( 'com_xmlsishandballv2' );
		$sis_offline = $content_params->get( 'sis_offline' );
		//$params = $this->get('params');
		if(!$sis_offline) {
			$sis_offline = 0;
		}
		//echo 'Daten-Update wird ausgeführt!<br>Params: '.$sis_offline.'<br>';

		if(strtotime($daten[0]->last_updated) < (time()-1800) && !$sis_offline) {
		// daten sind zu alt -> neue holen
			if( (strtotime($daten[0]->started_download) == NULL ) || (strtotime($daten[0]->started_download) < (time() - 120 ))) {
			// wir müssen aktiv werden, weil a) kein download läuft oder b) ein download scheinbar abgebrochen hat.
				// *** Wir sind dran mit dem Download - Sperre für andere Downloader einfügen.
				$db = Factory::getDbo();
				$query = $db->getQuery(true);
				// Fields to update.
				$fields = array(
					$db->quoteName('started_download') . ' = CURRENT_TIMESTAMP()'
				);
				
				// Conditions for which records should be updated.
					$conditions = array(
					$db->quoteName('liga_nr') . ' = ' . $db->quote($liganummer),
					$db->quoteName('sis_art') . ' = ' . $db->quote($sis_art)
					);

				$query->update($db->quoteName('#__xmlsishbv2_data'))->set($fields)->where($conditions);
				$db->setQuery($query);
				//$result = $db->query();
				$result = $db->execute();

				// *** Wir haben den Lock -> Starte den Download
				//$content = xmlsishandballv2Modelxmlsishandballv2::downloadData($linkresults,$linkparameters);
				$content = xmlsishandballv2Helper::downloadData($linkresults,$linkparameters);

				// *** Wir haben ein Ergebnis vom Download -> speichern in der DB
				$db = Factory::getDbo();
				$query = $db->getQuery(true);

				if($content != null) {
				// wenn vom download wirklich gültige Daten zurückgekommen sind (und kein timeout war usw), dann schreibe die neuen Daten in die Datenbank)
					
					// Fields to update.
					$fields = array(
						//$db->quoteName('started_download') . ' = ' .$db->quote(null),
						$db->quoteName('started_download') . ' = NULL',
						$db->quoteName('last_updated') . ' = CURRENT_TIMESTAMP()',
						$db->quoteName('content') . ' = ' .$db->quote($content)
					);
				} else {
				// ansonsten räume hinter mir auf und versuch's in 10 minuten nochmals

					// Fields to update.
					$fields = array(
						//$db->quoteName('started_download') . ' = ' .$db->quote(null),
						$db->quoteName('started_download') . ' = NULL',
						//$db->quoteName('last_updated') . ' = ' .$db->quote(time() - 120)
						//$db->quoteName('last_updated') . ' = CURRENT_TIMESTAMP() - 1200'
						$db->quoteName('last_updated') . ' = CURRENT_TIMESTAMP() - 10/1440'
					);

				}
				// Conditions for which records should be updated.
				$conditions = array(
					$db->quoteName('liga_nr') . ' = ' . $db->quote($liganummer),
					$db->quoteName('sis_art') . ' = ' . $db->quote($sis_art)
				);
				$query->update($db->quoteName('#__xmlsishbv2_data'))->set($fields)->where($conditions);
				$db->setQuery($query);
				//$result = $db->query();
				$result = $db->execute();
				
				//exit('If nach dummy und wir sind im else refreshData');

				// *** Cache ist jetzt aktuell oder zumindest stehen die alten Daten drinnen
			}

		}
	}

	public static function getUpdateTime($liganummer, $sis_art) {

		$db = Factory::getDbo();

		// Conditions for which records should be updated.
		$conditions = array(
			$db->quoteName('liga_nr') . ' = ' . $db->quote($liganummer),
			$db->quoteName('sis_art') . ' = ' . $db->quote($sis_art)
		);

		$query = $db->getQuery(true);
		$query->select($db->quoteName(array('last_updated')));
		$query->from($db->quoteName('#__xmlsishbv2_data'));
		$query->where($conditions);
 
		$db->setQuery($query);
		$UpdateTime = $db->loadObjectList();
		
		return $UpdateTime;
		
	}

	static function getLatestDataFromDatabase($liganummer,$sis_art) {
		$db = Factory::getDbo();

		// Conditions for which records should be updated.
		$conditions = array(
			$db->quoteName('liga_nr') . ' = ' . $db->quote($liganummer),
			$db->quoteName('sis_art') . ' = ' . $db->quote($sis_art)
		);

		$query = $db->getQuery(true);
		//$query->select('content','last_updated');
		$query->select($db->quoteName(array('content', 'last_updated')));
		$query->from($db->quoteName('#__xmlsishbv2_data'));
		$query->where($conditions);
 
		$db->setQuery($query);
		//$content = $db->loadResult();
		$content = $db->loadObjectList();

		return $content;
	}
	
	/*clublogo*/
	static function getClublogo($clubno) {
		$db = Factory::getDbo();

		// Conditions for which records should be updated.
		$conditions = array(
			$db->quoteName('clubno') . ' = ' . $db->quote($clubno)
		);

		$query = $db->getQuery(true);
		//$query->select('content','last_updated');
		$query->select($db->quoteName(array('clublogo')));
		$query->from($db->quoteName('#__xmlsishbv2_clubs'));
		$query->where($conditions);
 
		$db->setQuery($query);
		//$content = $db->loadResult();
		$content = $db->loadObjectList();

		return $content;
	}

	//get Vereinsdaten
	static function getTimezone($verein_user) {
		$db = Factory::getDbo();
		$query = $db->getQuery(true);
		//$query->select('vereinsnummer','vereinspasswort','nationurl');
		$query->select('*');
		//$query->select($db->quoteName(array('clublogo')));
		$query->from($db->quoteName('#__xmlsishbv2_verein'));
		$query->where('vereinsnummer = '. (int) $verein_user); 
		$db->setQuery($query);
		//$content = $db->loadResult();
		$vereindata = $db->loadObjectList();

		return $vereindata;
	}

}
